# Table of contents

* [Introduction](README.md)
* [About LDPL](about-ldpl/README.md)
  * [File Extensions](about-ldpl/file-extensions.md)
  * [Using the LDPL Compiler](about-ldpl/using-the-ldpl-compiler.md)
  * [LDPL Compiler Options](about-ldpl/ldpl-compiler-options.md)
* [Structure of LDPL Source Code](structure-of-ldpl-source-code/README.md)
  * [Comments in LDPL](structure-of-ldpl-source-code/comments-in-ldpl.md)
  * [DATA Section](structure-of-ldpl-source-code/data-section/README.md)
    * [Data Types](structure-of-ldpl-source-code/data-section/data-types.md)
  * [PROCEDURE Section](structure-of-ldpl-source-code/procedure-section.md)
  * [SUB-PROCEDUREs](structure-of-ldpl-source-code/sub-procedures.md)
* [Variables in LDPL](variables-in-ldpl/README.md)
  * [Usage of VECTORs](variables-in-ldpl/usage-of-vectors.md)
  * [Default Variable Values](variables-in-ldpl/default-variable-values.md)
  * [Command Line Arguments](variables-in-ldpl/command-line-arguments.md)
  * [Escape Sequences](variables-in-ldpl/escape-sequences.md)
* [Identifier Naming Schemes](naming-rules.md)

## Control Flow Statements

* [STORE - IN](control-flow-statements/store-in.md)
* [IF - IS - THEN](control-flow-statements/if-is-then/README.md)
  * [ELSE IF - IS - THEN](control-flow-statements/if-is-then/else-if-is-then.md)
* [WHILE - IS - DO](control-flow-statements/while-is-do.md)
* [BREAK](control-flow-statements/break.md)
* [CONTINUE](control-flow-statements/continue.md)
* [CALL SUB-PROCEDURE](control-flow-statements/call-sub-procedure.md)
* [RETURN](control-flow-statements/return.md)
* [EXIT](control-flow-statements/exit.md)
* [WAIT - MILLISECONDS](control-flow-statements/wait-milliseconds.md)
* [GOTO & LABEL](control-flow-statements/goto-and-label.md)

## Arithmetic Statements

* [ADD - AND - IN](arithmetic-operation-statements/add-and-in.md)
* [SUBTRACT - FROM - IN](arithmetic-operation-statements/subtract-from-in.md)
* [MULTIPLY - BY - IN](arithmetic-operation-statements/multiply-by-in.md)
* [DIVIDE - BY - IN](arithmetic-operation-statements/divide-by-in.md)
* [MODULO - BY - IN](arithmetic-operation-statements/modulo-by-in.md)
* [ABS](arithmetic-operation-statements/abs.md)
* [STORE RANDOM IN](arithmetic-operation-statements/store-random-in.md)
* [FLOOR](arithmetic-operation-statements/floor.md)
* [CEIL](arithmetic-operation-statements/ceil.md)
* [IN - SOLVE](arithmetic-operation-statements/in-solve.md)

## Text Statements

* [JOIN - AND - IN](text-statements/join-and-in.md)
* [GET CHARACTER AT - FROM - IN](text-statements/get-character-at-from-in.md)
* [STORE LENGTH OF - IN](text-statements/store-length-of-in.md)
* [STORE CHARACTER - IN](text-statements/store-character-in.md)
* [STORE CHARACTER CODE OF - IN](text-statements/store-character-code-of-in.md)
* [STORE QUOTE - IN](text-statements/store-quote-in.md)
* [IN - JOIN](text-statements/in-join.md)

## I/O Statements

* [DISPLAY](i-o-statements/display.md)
* [ACCEPT](i-o-statements/accept.md)
* [EXECUTE](i-o-statements/execute.md)
* [EXECUTE - AND STORE OUTPUT IN](i-o-statements/execute-and-store-output-in.md)
* [EXECUTE - AND STORE EXIT CODE IN](i-o-statements/execute-and-store-exit-code-in.md)
* [ACCEPT - UNTIL EOF](i-o-statements/accept-until-eof.md)
* [LOAD FILE - IN](i-o-statements/load-file-in.md)
* [WRITE - TO FILE](i-o-statements/write-to-file.md)
* [APPEND - TO FILE](i-o-statements/append-to-file.md)

## Extensions

* [C++ Extensions](extensions/c++-extensions/README.md)
  * [Writing C++ Extensions](extensions/c++-extensions/writing-c++-extensions.md)
  * [Building C++ Extensions](extensions/c++-extensions/building-c++-extensions.md)
  * [External Identifier Naming Scheme](extensions/c++-extensions/external-identifier-naming-scheme.md)
  * ["Hello World" C++ Example](extensions/c++-extensions/hello-world-c++-example.md)
  * [More Examples](extensions/c++-extensions/more-examples.md)
* [CALL EXTERNAL](extensions/call-external.md)
* [EXTERNAL Variables](extensions/external-variables.md)

